@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1399,9 +1399,19 @@ void Playlist::load() {
 			if (suffix == "xspf") {
 				loadXSPF(s);
 			}
-			else {
+			else
+			if (suffix == "m3u") {
 				load_m3u(s);
 			}
+			else {
+				QMessageBox::warning(this, tr("Wrong playlist"),
+					tr("It wasn't possible to load '%1'.\n"
+				"Playlist file name must end with a specific suffix "
+				"which is pls, xspf or m3u. '%2' is not supported. "
+				"Please, choose once again!").arg(s).arg(suffix));
+				//Rechoose again
+				load();
+			}
 			//listView->resizeColumnsToContents();
 		}
 	}
